==> Goober_0_1_1.zip: goober-ionic/src/pages/stream/stream.ts <==
import { Component } from '@angular/core';
import { ViewController, NavController, NavParams, ModalController } from 'ionic-angular';
import { ThreadPage } from '../thread/thread';

import * as pnut from 'pnut-butter';

/**
 * Generated class for the StreamPage page.
 *
 * See http://ionicframework.com/docs/components/#navigation for more info
 * on Ionic pages and navigation.
 */
@Component({
  selector: 'page-stream',
  templateUrl: 'stream.html',
})
export class StreamPage {

  title: string;
  posts: Array<Object> = [];
  since_id: string;
  before_id: string;
  fetcher: any;

  constructor(public navCtrl: NavController, public navParams: NavParams, public modalCtrl: ModalController) {
    // console.log(JSON.stringify(navParams));
    switch (navParams.data.stream) {
      case 'global':
        this.title = 'Global';
        this.fetcher = pnut.global;
        this.fetchPosts();
        break;
      case 'personal':
        this.title = 'Home';
        this.fetcher = pnut.personal;
        this.fetchPosts();
        break;
    }
  }

  fetchOlderPosts(infiniteScroll) {
    this.fetcher({include_raw: 1, before_id: this.before_id, count: 40}).then(res => {
      if (res.data.length > 0) {
        this.posts.push.apply(this.posts, res.data);
        this.before_id = res.meta.min_id;
      }
      console.log('since_id: ' + this.since_id);
      console.log('before_id: ' + this.before_id);
      infiniteScroll.complete();
    }).catch(err => {
      console.log(err);
    });
  }

  fetchNewerPosts(refresher) {
    this.fetcher({include_raw: 1, since_id: this.since_id, count: 40}).then(res => {
      if (res.data.length > 0) {
        Array.prototype.unshift.apply(this.posts, res.data);
        this.since_id = res.meta.max_id;
      }
      console.log('since_id: ' + this.since_id);
      console.log('before_id: ' + this.before_id);
      refresher.complete();
    }).catch(err => {
      console.log(err);
    });
  }

  fetchPosts() {
    console.log('-- fetching global stream --');
    this.fetcher({include_raw: 1, count: 40}).then(res => {
      this.posts = res.data;
      this.since_id = res.meta.max_id;
      this.before_id = res.meta.min_id;
      console.log('since_id: ' + this.since_id);
      console.log('before_id: ' + this.before_id);
    }).catch(err => {
      console.log(err);
    });
  }

  fetchThread(threadid) {
    pnut.thread(threadid).then(res => {
      this.navCtrl.push(ThreadPage, {posts: res.data});
    }).catch(err => {
      console.log(err);
    });
  }

  bookmark(postid, bookmarked) {
    if (bookmarked) {
      pnut.deleteBookmark(postid).then(res => {
        console.log(res);
        this.updatePost(res.data.id);
      }).catch(err => {
        console.log(err);
      });
    } else {
      pnut.bookmark(postid).then(res => {
        console.log(res);
        this.updatePost(res.data.id);
      }).catch(err => {
        console.log(err);
      });
    }
  }

  repost(postid, reposted) {
    if (reposted) {
      pnut.deleteRepost(postid).then(res => {
        console.log(res);
        this.updatePost(res.data.id);
      }).catch(err => {
        console.log(err);
      });
    } else {
      pnut.repost(postid).then(res => {
        console.log(res);
        this.updatePost(res.data.id);
      }).catch(err => {
        console.log(err);
      });
    }
  }

  updatePost(postid) {
    pnut.post(postid, {include_raw: 1}).then(res => {
      for (var i = 0; i < this.posts.length; i++) {
        if (this.posts[i]['id'] === postid) {
          this.posts[i] = res.data;
          break;
        }
      }
    }).catch(err => {
      console.log(err);
    });
  }

  showNewPost() {
    let newPostModal = this.modalCtrl.create(NewPostModal);
    newPostModal.present();
  }

  showReplyPost(postData) {
    let newPostModal = this.modalCtrl.create(NewPostModal, {type: 'reply', post: postData});
    newPostModal.present();
  }

  showQuotedPost(postData) {
    console.log(postData);
    let newPostModal = this.modalCtrl.create(NewPostModal, {type: 'quote', post: postData});
    newPostModal.present();
  }

}

@Component({
  // templateUrl: 'new-post.html'
  template: `
<ion-header>
  <ion-toolbar>

    <ion-buttons start>
      <button ion-button (click)="dismiss()">
        <span ion-text color="primary">Cancel</span>
      </button>
    </ion-buttons>

    <ion-title>{{ title }}</ion-title>

  </ion-toolbar>
</ion-header>

<ion-content>
  <ion-card>
    <ion-card-content>
      <ion-item>
        <ion-textarea [(ngModel)]="ptext" autocomplete="true" spellcheck="true"></ion-textarea>
      </ion-item>
    </ion-card-content>
    <ion-row justify-content-end>
      <ion-col col-2>
        <button ion-button (click)="send()">
          <ion-icon name="send"></ion-icon>
        </button>
      </ion-col>
    </ion-row>
  </ion-card>
</ion-content>
`
})
export class NewPostModal {
  title: string;
  replyid: string;
  ptext: string;
  options: Object;

  constructor(public navParams: NavParams, public viewCtrl: ViewController) {
    console.log(this.navParams);
    if (navParams.data.type === 'reply') {
      this.replyid = navParams.data.post.id;
      this.options = {replyTo: this.replyid};
      this.ptext = "@" + navParams.data.post.user.username + " ";
      if (navParams.data.post.content.entities) {
        if (navParams.data.post.content.entities.mentions) {
          this.ptext = this.ptext + this.parseMentions(navParams.data.post.content.entities.mentions);
        }
      }
      this.title = "Reply to " + navParams.data.post.user.username
    } else if (navParams.data.type === 'quote') {
      this.ptext = " >> @" + navParams.data.post.user.username + ": " + navParams.data.post.content.text;
      this.title = "New Post";
    } else {
      this.title = "New Post";
    }
  }

  dismiss() {
   this.viewCtrl.dismiss();
  }

  send() {
    console.log(this.ptext);
    pnut.createPost(this.ptext, this.options).then(res => {
      console.log(res);
    }).catch(err => {
      console.log(err);
    });
    this.viewCtrl.dismiss();
  }

  parseMentions(mentions) {
    let mtext = ""
    for(var i = 0; i < mentions.length; i++) {
      let mu = mentions[i].text;
      mtext += "@" + mu + " ";
    }
    if (mtext.length > 0) {
      return mtext;
    } else {
      return "";
    }
  }
}

==> Goober_0_2_0.zip: goober-ionic/src/pages/stream/stream.ts <==
import { Component } from '@angular/core';
import { ViewController, NavController, NavParams, ModalController } from 'ionic-angular';
import { ThreadPage } from '../thread/thread';

import * as pnut from 'pnut-butter';

/**
 * Generated class for the StreamPage page.
 *
 * See http://ionicframework.com/docs/components/#navigation for more info
 * on Ionic pages and navigation.
 */
@Component({
  selector: 'page-stream',
  templateUrl: 'stream.html',
})
export class StreamPage {

  title: string;
  posts: Array<Object> = [];
  since_id: string;
  before_id: string;
  fetcher: any;
  fcaller: any;
  myUsername: string;

  constructor(public navCtrl: NavController, public navParams: NavParams, public modalCtrl: ModalController) {
    // console.log(JSON.stringify(navParams));
    switch (navParams.data.stream) {
      case 'global':
        this.title = 'Global';
        this.fetcher = pnut.global;
        this.fetchPosts();
        break;
      case 'personal':
        this.title = 'Timeline';
        this.fetcher = pnut.personal;
        this.fetchPosts();
        break;
      case 'mentions':
        this.title = 'Mentions';
        this.fetcher = pnut.mentions;
        this.fetchMyPosts();
        break;
      case 'bookmarks':
        this.title = 'Bookmarks';
        this.fetcher = pnut.bookmarks;
        this.fetchMyPosts();
        break;
    }
    pnut.user('me').then(res => {
      this.myUsername = res.data.username;
    }).catch(err => {
      console.log(err);
    });
  }

  fetchOlderPosts(infiniteScroll) {
    let params = {include_raw: 1, before_id: this.before_id, count: 40};
    if (this.title === 'Mentions') {
      this.fcaller = this.fetcher('me', params);
    } else {
      this.fcaller = this.fetcher(params);
    }
    this.fcaller.then(res => {
      if (res.data.length > 0) {
        this.posts.push.apply(this.posts, res.data);
        this.before_id = res.meta.min_id;
      }
      console.log('since_id: ' + this.since_id);
      console.log('before_id: ' + this.before_id);
      infiniteScroll.complete();
    }).catch(err => {
      console.log(err);
    });
  }

  fetchNewerPosts(refresher) {
    let params = {include_raw: 1, since_id: this.since_id, count: 40};
    if (this.title === 'Mentions') {
      this.fcaller = this.fetcher('me', params);
    } else {
      this.fcaller = this.fetcher(params);
    }
    this.fcaller.then(res => {
      if (res.data.length > 0) {
        Array.prototype.unshift.apply(this.posts, res.data);
        this.since_id = res.meta.max_id;
      }
      console.log('since_id: ' + this.since_id);
      console.log('before_id: ' + this.before_id);
      refresher.complete();
    }).catch(err => {
      console.log(err);
    });
  }

  fetchPosts() {
    console.log('-- fetching global stream --');
    this.fetcher({include_raw: 1, count: 40}).then(res => {
      this.posts = res.data;
      this.since_id = res.meta.max_id;
      this.before_id = res.meta.min_id;
      console.log('since_id: ' + this.since_id);
      console.log('before_id: ' + this.before_id);
    }).catch(err => {
      console.log(err);
    });
  }

  fetchThread(threadid) {
    pnut.thread(threadid, {include_raw: 1, count: 140}).then(res => {
      this.navCtrl.push(ThreadPage, {posts: res.data});
    }).catch(err => {
      console.log(err);
    });
  }

  fetchMyPosts() {
    console.log('-- fetching mentions --');
    this.fetcher('me', {include_raw: 1, count: 40}).then(res => {
      this.posts = res.data;
      this.since_id = res.meta.max_id;
      this.before_id = res.meta.min_id;
      console.log('since_id: ' + this.since_id);
      console.log('before_id: ' + this.before_id);
    }).catch(err => {
      console.log(err);
    });
  }

  bookmark(postid, bookmarked) {
    if (bookmarked) {
      pnut.deleteBookmark(postid).then(res => {
        console.log(res);
        this.updatePost(res.data.id);
      }).catch(err => {
        console.log(err);
      });
    } else {
      pnut.bookmark(postid).then(res => {
        console.log(res);
        this.updatePost(res.data.id);
      }).catch(err => {
        console.log(err);
      });
    }
  }

  repost(postid, reposted) {
    if (reposted) {
      pnut.deleteRepost(postid).then(res => {
        console.log(res);
        this.updatePost(res.data.id);
      }).catch(err => {
        console.log(err);
      });
    } else {
      pnut.repost(postid).then(res => {
        console.log(res);
        this.updatePost(res.data.id);
      }).catch(err => {
        console.log(err);
      });
    }
  }

  updatePost(postid) {
    pnut.post(postid, {include_raw: 1}).then(res => {
      for (var i = 0; i < this.posts.length; i++) {
        if (this.posts[i]['id'] === postid) {
          this.posts[i] = res.data;
          break;
        }
      }
    }).catch(err => {
      console.log(err);
    });
  }

  showNewPost() {
    let newPostModal = this.modalCtrl.create(NewPostModal);
    newPostModal.present();
  }

  showReplyPost(postData) {
    let newPostModal = this.modalCtrl.create(NewPostModal, {type: 'reply', post: postData, me: this.myUsername});
    newPostModal.present();
  }

  showQuotedPost(postData) {
    console.log(postData);
    let newPostModal = this.modalCtrl.create(NewPostModal, {type: 'quote', post: postData, me: this.myUsername});
    newPostModal.present();
  }

}

@Component({
  // templateUrl: 'new-post.html'
  selector: 'modal-newpost',
  template: `
<ion-header>
  <ion-toolbar>

    <ion-buttons start>
      <button ion-button (click)="dismiss()">
        <span ion-text color="primary">Cancel</span>
      </button>
    </ion-buttons>

    <ion-title>{{ title }}</ion-title>

  </ion-toolbar>
</ion-header>

<ion-content>
  <ion-card>
    <ion-card-content>
      <ion-item>
        <ion-textarea [(ngModel)]="ptext" autocomplete="true" spellcheck="true" clearInput="true" rows="8"></ion-textarea>
      </ion-item>
    </ion-card-content>
    <ion-row justify-content-end>
      <ion-col col-2><div text-center>{{254 - ptext.length}}</div></ion-col>
      <ion-col col-2>
        <button ion-button (click)="send()">
          <ion-icon name="send"></ion-icon>
        </button>
      </ion-col>
    </ion-row>
  </ion-card>
</ion-content>
`
})
export class NewPostModal {
  title: string;
  replyid: string;
  ptext: string = "";
  options: Object;
  myUsername: string;

  constructor(public navParams: NavParams, public viewCtrl: ViewController) {
    console.log(this.navParams);
    this.myUsername = navParams.data.me;
    if (navParams.data.type === 'reply') {
      this.replyid = navParams.data.post.id;
      this.options = {replyTo: this.replyid};
      this.ptext = "@" + navParams.data.post.user.username + " ";
      if (navParams.data.post.content.entities) {
        if (navParams.data.post.content.entities.mentions) {
          this.ptext = this.ptext + this.parseMentions(navParams.data.post.content.entities.mentions);
        }
      }
      this.title = "Reply to " + navParams.data.post.user.username
    } else if (navParams.data.type === 'quote') {
      this.ptext = " >> @" + navParams.data.post.user.username + ": " + navParams.data.post.content.text;
      this.title = "New Post";
    } else {
      this.title = "New Post";
    }
  }

  dismiss() {
   this.viewCtrl.dismiss();
  }

  send() {
    console.log(this.ptext);
    pnut.createPost(this.ptext, this.options).then(res => {
      console.log(res);
    }).catch(err => {
      console.log(err);
    });
    this.viewCtrl.dismiss();
  }

  parseMentions(mentions) {
    let mtext = ""
    for(var i = 0; i < mentions.length; i++) {
      let mu = mentions[i].text;
      if (mu !== this.myUsername) {
        mtext += "@" + mu + " ";
      }
    }
    if (mtext.length > 0) {
      return mtext;
    } else {
      return "";
    }
  }
}
